nx.geometry.BezierCurve - Next UI Toolkit

#

API Docs for: trial
Show: Inherited Protected Private Deprecated

# nx.geometry.BezierCurve Class

Module: nx.geometry

- Index
- Methods

## Item Index

### Methods

- separate

## Methods

### `separate`

(

- `polyline`
- `rate`

)
Point:x, y, left: leftPolyline, right: rightPolyline

#### Parameters:

- `polyline` Object

  List of intervals (interval=[point-from, point-to], point=[x, y]).

- `rate` Object

  The rate to separate.

#### Returns:

Point:x, y, left: leftPolyline, right: rightPolyline: